-- About GoogleScholarSearch.lua
--
-- GoogleScholarSearch.lua does a Google Scholar search for the PhotoArticleTitle for articles.
-- autoSearch (boolean) determines whether the search is performed automatically when a request is opened or not.

local settings = {};
settings.AutoSearch = GetSetting("AutoSearch");

local interfaceMngr = nil;
local googleSearchForm = {};
googleSearchForm.Form = nil;
googleSearchForm.Browser = nil;
googleSearchForm.RibbonPage = nil;

require "Atlas.AtlasHelpers";

function Init()
	if GetFieldValue("Item", "ItemType") == "SER" then
		interfaceMngr = GetInterfaceManager();
		
		-- Create a form
		googleSearchForm.Form = interfaceMngr:CreateForm("Google Scholar Search", "Script");
		
		-- Add a browser
		googleSearchForm.Browser = googleSearchForm.Form:CreateBrowser("Google Scholar Search", "Google Scholar Search Browser", "Google Scholar Search");
		
		-- Hide the text label
		googleSearchForm.Browser.TextVisible = false;
		
		-- Since we didn't create a ribbon explicitly before creating our browser, it will have created one using the name we passed the CreateBrowser method.  We can retrieve that one and add our buttons to it.
		googleSearchForm.RibbonPage = googleSearchForm.Form:GetRibbonPage("Google Scholar Search");
		
		-- Create the search button
		googleSearchForm.RibbonPage:CreateButton("Search", GetClientImage("Search32"), "Search", "Google Scholar");
		
		-- After we add all of our buttons and form elements, we can show the form.
		googleSearchForm.Form:Show();
		
		googleSearchForm.Form:LoadLayout("layout.xml");
		
		if settings.AutoSearch then
			Search();
		end
	end
end

function Search()
	if GetFieldValue("Item", "ArticleTitle") ~= nil then
		googleSearchForm.Browser:Navigate("http://scholar.google.com/scholar?q=" .. AtlasHelpers.UrlEncode(GetFieldValue("Item", "ArticleTitle")));	
	end
end



